==> tuia-advert-center-api-2.5.50-sources.jar: cn/com/duiba/tuia/core/api/dto/autoReflow/AutoReflowQueryAppDetailDataInfo.java <==
package cn.com.duiba.tuia.core.api.dto.autoReflow;

public class AutoReflowQueryAppDetailDataInfo {

    private Long accountId;

    private Long extGroupId;

    private String flowTime;

    private Long exposurePv;

    private Long clickPv;

    private Long downPv;

    private Long totalConsume;

    /**
     * 后端转化pv
     */
    private Long backendPv;

    private Long autoReflowPlanId;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getExtGroupId() {
        return extGroupId;
    }

    public void setExtGroupId(Long extGroupId) {
        this.extGroupId = extGroupId;
    }

    public String getFlowTime() {
        return flowTime;
    }

    public void setFlowTime(String flowTime) {
        this.flowTime = flowTime;
    }

    public Long getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Long exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Long getClickPv() {
        return clickPv;
    }

    public void setClickPv(Long clickPv) {
        this.clickPv = clickPv;
    }

    public Long getDownPv() {
        return downPv;
    }

    public void setDownPv(Long downPv) {
        this.downPv = downPv;
    }

    public Long getTotalConsume() {
        return totalConsume;
    }

    public void setTotalConsume(Long totalConsume) {
        this.totalConsume = totalConsume;
    }

    public Long getBackendPv() {
        return backendPv;
    }

    public void setBackendPv(Long backendPv) {
        this.backendPv = backendPv;
    }

    public Long getAutoReflowPlanId() {
        return autoReflowPlanId;
    }

    public void setAutoReflowPlanId(Long autoReflowPlanId) {
        this.autoReflowPlanId = autoReflowPlanId;
    }
}

==> tuia-advert-center-api-2.5.80-sources.jar: cn/com/duiba/tuia/core/api/dto/autoReflow/AutoReflowQueryAppDetailDataInfo.java <==
package cn.com.duiba.tuia.core.api.dto.autoReflow;

public class AutoReflowQueryAppDetailDataInfo {

    private String accountId;

    private Long extGroupId;

    private String flowTime;

    private Long exposurePv;

    private Long clickPv;

    private Long downPv;

    private Long totalConsume;

    /**
     * 后端转化pv
     */
    private Long backendPv;

    private Long autoReflowPlanId;

    public String getAccountId() {
        return accountId;
    }

    public void setAccountId(String accountId) {
        this.accountId = accountId;
    }

    public Long getExtGroupId() {
        return extGroupId;
    }

    public void setExtGroupId(Long extGroupId) {
        this.extGroupId = extGroupId;
    }

    public String getFlowTime() {
        return flowTime;
    }

    public void setFlowTime(String flowTime) {
        this.flowTime = flowTime;
    }

    public Long getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Long exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Long getClickPv() {
        return clickPv;
    }

    public void setClickPv(Long clickPv) {
        this.clickPv = clickPv;
    }

    public Long getDownPv() {
        return downPv;
    }

    public void setDownPv(Long downPv) {
        this.downPv = downPv;
    }

    public Long getTotalConsume() {
        return totalConsume;
    }

    public void setTotalConsume(Long totalConsume) {
        this.totalConsume = totalConsume;
    }

    public Long getBackendPv() {
        return backendPv;
    }

    public void setBackendPv(Long backendPv) {
        this.backendPv = backendPv;
    }

    public Long getAutoReflowPlanId() {
        return autoReflowPlanId;
    }

    public void setAutoReflowPlanId(Long autoReflowPlanId) {
        this.autoReflowPlanId = autoReflowPlanId;
    }
}
